package com.ruoyi.project.shiftmgr.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.shiftmgr.mapper.TShiftDevelopmentMapper;
import com.ruoyi.project.shiftmgr.domain.TShiftDevelopment;
import com.ruoyi.project.shiftmgr.service.ITShiftDevelopmentService;

/**
 * 班组建设Service业务层处理
 *
 * @author ruoyi
 * @date 2022-07-29
 */
@Service
public class TShiftDevelopmentServiceImpl implements ITShiftDevelopmentService
{
    @Autowired
    private TShiftDevelopmentMapper tShiftDevelopmentMapper;

    /**
     * 查询班组建设
     *
     * @param id 班组建设ID
     * @return 班组建设
     */
    @Override
    public TShiftDevelopment selectTShiftDevelopmentById(Long id)
    {
        return tShiftDevelopmentMapper.selectTShiftDevelopmentById(id);
    }

    /**
     * 查询班组建设列表
     *
     * @param tShiftDevelopment 班组建设
     * @return 班组建设
     */
    @Override
    public List<TShiftDevelopment> selectTShiftDevelopmentList(TShiftDevelopment tShiftDevelopment)
    {
        return tShiftDevelopmentMapper.selectTShiftDevelopmentList(tShiftDevelopment);
    }

    /**
     * 新增班组建设
     *
     * @param tShiftDevelopment 班组建设
     * @return 结果
     */
    @Override
    public int insertTShiftDevelopment(TShiftDevelopment tShiftDevelopment)
    {
        return tShiftDevelopmentMapper.insertTShiftDevelopment(tShiftDevelopment);
    }

    /**
     * 修改班组建设
     *
     * @param tShiftDevelopment 班组建设
     * @return 结果
     */
    @Override
    public int updateTShiftDevelopment(TShiftDevelopment tShiftDevelopment)
    {
        return tShiftDevelopmentMapper.updateTShiftDevelopment(tShiftDevelopment);
    }

    /**
     * 批量删除班组建设
     *
     * @param ids 需要删除的班组建设ID
     * @return 结果
     */
    @Override
    public int deleteTShiftDevelopmentByIds(Long[] ids)
    {
        return tShiftDevelopmentMapper.deleteTShiftDevelopmentByIds(ids);
    }

    /**
     * 删除班组建设信息
     *
     * @param id 班组建设ID
     * @return 结果
     */
    @Override
    public int deleteTShiftDevelopmentById(Long id)
    {
        return tShiftDevelopmentMapper.deleteTShiftDevelopmentById(id);
    }
}
